@@ -260,7 +260,7 @@ class Stack:
 
     def push(self, item, exists_function=None, logger=None):
         if callable(exists_function):
-            if exists_function(item) == False:
+            if exists_function(item, self.stack) == False:
                 self.stack.append(item)
                 if isinstance(logger, Logger):
                     logger.debug(f'self.stack.append: {item}')
