@@ -10,6 +10,10 @@ def IsBitOn(value, bit):
         return res
     return (value & (1 << bit))._value != 0
 
+def IsBitOnBool(value, bit):
+    res = IsBitOn(value=value, bit=bit)
+    return True if res == 1 else False
+
 
 def IsBitOff(value, bit):
     return not IsBitOn(value, bit)
